@@ -19,13 +19,10 @@ def post(
         content: str,
         post_type: int,
         sign_file) -> None:
-    cmd_list = []
-    cmd_list.append(command.GoMainMenu)
-    cmd_list.append('qs')
-    cmd_list.append(board)
-    cmd_list.append(command.Enter)
-    cmd_list.append(command.Ctrl_C * 2)
-    cmd_list.append(command.Space)
+
+    api._goto_board(board)
+
+    cmd_list = list()
     cmd_list.append(command.Ctrl_P)
 
     cmd = ''.join(cmd_list)
@@ -40,18 +37,23 @@ def post(
             i18n.NoPermission,
             '使用者不可發言',
             break_detect=True,
-        )
+        ),
+        connect_core.TargetUnit(
+            i18n.NoPermission,
+            '無法發文: 未達看板要求權限',
+            break_detect=True
+        ),
     ]
     index = api.connect_core.send(cmd, target_list)
     if index < 0:
         screens.show(api.config, api.connect_core.get_screen_queue())
         raise exceptions.UnknownError(i18n.UnknownError)
-    if index == 1:
+    if index == 1 or index == 2:
         raise exceptions.NoPermission(i18n.NoPermission)
 
     screens.show(api.config, api.connect_core.get_screen_queue())
 
-    cmd_list = []
+    cmd_list = list()
     cmd_list.append(str(post_type))
     cmd_list.append(command.Enter)
     cmd_list.append(str(title))
