@@ -24,6 +24,8 @@ except ModuleNotFoundError:
     import command
     import exceptions
 
+# new_event_loop = list()
+
 
 class connect_mode(object):
     TELNET = 1
@@ -206,6 +208,9 @@ class API(object):
 
         connect_success = False
 
+        # global new_event_loop
+        # thread_id = threading.get_ident()
+
         for _ in range(2):
 
             try:
@@ -215,6 +220,8 @@ class API(object):
 
                 else:
 
+                    # if thread_id not in new_event_loop:
+                    #     new_event_loop.append(thread_id)
                     try:
                         loop = asyncio.new_event_loop()
                         asyncio.set_event_loop(loop)
@@ -362,6 +369,7 @@ class API(object):
                         recv_data_obj.data = self._core.read_very_eager()
                     except EOFError:
                         return -1
+
                 else:
                     try:
 
@@ -380,6 +388,8 @@ class API(object):
                         raise exceptions.ConnectionClosed()
                     except asyncio.TimeoutError:
                         return -1
+                    except RuntimeError:
+                        raise exceptions.ConnectionClosed()
 
                 receive_data_buffer += recv_data_obj.data
                 receive_data_temp = receive_data_buffer.decode(
