@@ -231,8 +231,7 @@ class NoSuchPost(Exception):
         self.message = i18n.replace(
             i18n.NoSuchPost,
             board,
-            aid
-        )
+            aid)
 
     def __str__(self):
         return self.message
@@ -286,3 +285,14 @@ class OnlySecureConnection(Exception):
 
     def __str__(self):
         return self.message
+
+
+class DeletedPost(Exception):
+    def __init__(self, board, aid):
+        self.message = i18n.replace(
+            i18n.DeletedPost,
+            board,
+            aid)
+
+    def __str__(self):
+        return self.message
